summaryrefslogtreecommitdiffstats
path: root/generic/tclNamesp.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tclNamesp.c')
-rw-r--r--generic/tclNamesp.c11
1 files changed, 7 insertions, 4 deletions
diff --git a/generic/tclNamesp.c b/generic/tclNamesp.c
index 717eaf9..dab46fc 100644
--- a/generic/tclNamesp.c
+++ b/generic/tclNamesp.c
@@ -23,7 +23,7 @@
* See the file "license.terms" for information on usage and redistribution of
* this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclNamesp.c,v 1.162.2.2 2008/05/22 15:25:54 dgp Exp $
+ * RCS: @(#) $Id: tclNamesp.c,v 1.162.2.3 2008/07/21 19:38:19 andreas_kupries Exp $
*/
#include "tclInt.h"
@@ -3279,12 +3279,15 @@ NamespaceEvalCmd(
if (objc == 4) {
/*
* TIP #280: Make invoker available to eval'd script.
*/
- Interp *iPtr = (Interp *) interp;
+ Interp *iPtr = (Interp *) interp;
+ CmdFrame* invoker = iPtr->cmdFramePtr;
+ int word = 3;
- result = TclEvalObjEx(interp, objv[3], 0, iPtr->cmdFramePtr, 3);
+ TclArgumentGet (interp, objv[3], &invoker, &word);
+ result = TclEvalObjEx(interp, objv[3], 0, invoker, word);
} else {
/*
* More than one argument: concatenate them together with spaces
@@ -3279,12 +3279,15 @@ NamespaceEvalCmd(
if (objc == 4) {
/*
- * TIP #280: Make invoker available to eval'd script.
+ * TIP #280: Make actual argument location available to eval'd script.
*/